var createError = require('http-errors');
var express = require('express');
var path = require('path');
var cookieParser = require('cookie-parser');
var logger = require('morgan');
var connection = require('./connection');

const SerialPort = require('serialport');
const Readline = require('@serialport/parser-readline');

var indexRouter = require('./routes/index');
var usersRouter = require('./routes/users');

var app = express();

// view engine setup
app.set('views', path.join(__dirname, 'views'));
app.set('view engine', 'hbs');

app.use(logger('dev'));
app.use(express.json());
app.use(express.urlencoded({ extended: false }));
app.use(cookieParser());
app.use(express.static(path.join(__dirname, 'public')));

app.use('/', indexRouter);
app.use('/users', usersRouter);

// catch 404 and forward to error handler
app.use(function(req, res, next) {
  next(createError(404));
});

// error handler
app.use(function(err, req, res, next) {
  // set locals, only providing error in development
  res.locals.message = err.message;
  res.locals.error = req.app.get('env') === 'development' ? err : {};

  // render the error page
  res.status(err.status || 500);
  res.render('error');
});

// Connexion avec l'arduino
app.arduinoConnection = [];
try{
  const port = new SerialPort('/dev/ttyACM0', { baudRate: 9600 });
  const parser = port.pipe(new Readline({ delimiter: '\n' }));
  // Read the port data
  port.on("open", () => {
    console.log('serial port open');
  });
  parser.on('data', data =>{
    let message = {};
    if(data.substring(0,("distance: ").length) == "distance: "){
      let distance = parseInt(data.substring(("distance: ").length));
      message = {
        type: "distance",
        value: distance
      };
    }else if(data.substring(0,("wheels: ").length) == "wheels: "){
      let wheels = parseInt(data.substring(("wheels: ").length));
      message = {
        type: "wheels",
        value: wheels
      };
    }
    app.arduinoConnection.push(message);
  }); 
}catch(exp){
  console.log(exp.message);
}
module.exports = app;
